package com.simaek.notify.wechat;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.simaek.notify.*;
import com.simaek.notify.template.AbstractTemplateManager;
import com.simaek.notify.template.Template;
import com.simaek.notify.template.TemplateManager;
import com.simaek.notify.template.TemplateProperties;
import com.simaek.notify.wechat.subscription.WechatSubscriptionNotifierProvider;
import org.junit.Test;

import java.util.HashMap;
import java.util.Map;

/**
 * @author xueye
 */
public class WechatSubscriptionTest {
    @Test
    public void test() {
        // 通知器配置管理器
        NotifyConfigManager notifyConfigManager = (notifyType, configId) -> {
            NotifierProperties notifierProperties = new NotifierProperties();
            notifierProperties.setType(DefaultNotifyType.wechat.getId());
            notifierProperties.setProvider(WechatProvider.subscription.getId());
            notifierProperties.setId("12");

            Map<String, Object> config = new HashMap<>();
            config.put("grantType", "client_credential");
            config.put("appId", "wx080f08f17aab234a");
            config.put("secret", "2d782a5d9cafecdb1e0448c97e092e24");
            notifierProperties.setConfiguration(config);

            return notifierProperties;
        };

        // 模板管理器
        TemplateManager templateManager = new AbstractTemplateManager() {
            @Override
            protected TemplateProperties getProperties(NotifyType type, String id) {
                TemplateProperties templateProperties = new TemplateProperties();
                templateProperties.setType(DefaultNotifyType.wechat.getId());
                templateProperties.setProvider(WechatProvider.subscription.getId());

                JSONObject jsonObject = new JSONObject();
                jsonObject.put("toUser", "oOwtw6GaMogfIsrjV9WGdo2A1t5g");
                jsonObject.put("templateId", "DMz3nRo41CUZg4Og7DUN2QHLDwQSJ5hs9eB6oq-V8Uc");
                Map<String, Object> data = new HashMap<>();
                Map<String, Object> keyword = new HashMap<>();
                keyword.put("value", "xueye");
                keyword.put("color", "#173177");
                data.put("Hello", keyword);
                jsonObject.put("data", data);

                templateProperties.setTemplate(JSON.toJSONString(jsonObject));
                return templateProperties;
            }
        };

        NotifierManager notifierManager = new AbstractNotifierManager(notifyConfigManager){};

        // register
        WechatSubscriptionNotifierProvider provider = new WechatSubscriptionNotifierProvider();
        notifierManager.register(provider);
        templateManager.register(provider);

        Notifier<Template> notifier = notifierManager.getNotifier(DefaultNotifyType.wechat, "123");
        notifier.send(templateManager.getTemplate(DefaultNotifyType.wechat, "124"), new HashMap<>());
    }
}
